@@ -3,8 +3,9 @@
 #' Calculates weighting for a model. Each record receives a numeric weight.
 #'
 #' @param w Either logical in which case \code{TRUE} (default) causes the total weight of presences to equal the total weight of absences (if \code{family='binomial'}) \emph{or} a numeric list of weights, one per row in \code{data} \emph{or} the name of the column in \code{data} that contains site weights. If \code{FALSE}, then each datum gets a weight of 1.
-#' @param Data frame
+#' @param data Data frame
 #' @param resp Name of response column
+#' @param family Name of family
 #'
 #' @returns A numeric vector.
 #' @keywords internal
@@ -16,6 +17,8 @@
 		family
 	}
 
+	if (inherits(data, 'data.table')) data <- as.data.frame(data)
+
 	if (inherits(w, 'logical')) {
 
 		if (w & (fam %in% c('binomial', 'quasibinomial'))) {
